@@ -1,5 +1,5 @@
 package Archive::Raw::DiskWriter;
-$Archive::Raw::DiskWriter::VERSION = '0.01';
+$Archive::Raw::DiskWriter::VERSION = '0.02';
 use strict;
 use warnings;
 use Archive::Raw;
@@ -10,7 +10,7 @@ Archive::Raw::DiskWriter - libarchive DiskWriter class
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -24,7 +24,7 @@ Create a new disk writer.
 
 =head2 write( $entry )
 
-Write C<$entry> to disk. C<$entry> should be an C<Archive::Raw::Entry> object.
+Write C<$entry> to disk. C<$entry> should be an L<C<Archive::Raw::Entry>> object.
 
 =head1 AUTHOR
 
